import * as React from 'react';
import { useEffect, Suspense } from 'react';
import { BrowserRouter as Router, Routes, Route } from 'react-router-dom';
import { ThemeProvider } from './contexts/ThemeContext';
import { useUpackuTranslation } from './utils/i18nHelper';
import './i18n';
import { SEO } from './components/seo';
import PerformanceMonitor from './components/performance/PerformanceMonitor';

// Hooks d'optimisation SEO
import { useSEOPerformanceOptimizer } from './hooks/useSEOPerformanceOptimizer';
import { useSEOPerformance } from './hooks/useSEOPerformance';

// Composants d'optimisation des performances
import { CriticalResourceLoader } from './components/shared/CriticalResourceLoader';
import { useServiceWorker } from './utils/serviceWorkerManager';

// Layout Components (critiques - chargés immédiatement)
import Navbar from './components/layout/Navbar';
import Footer from './components/layout/Footer';

// Page Components avec lazy loading pour optimiser les performances
const HomePage = React.lazy(() => import('./components/pages/HomePage'));
const SEOTrackerPage = React.lazy(() => import('./components/pages/SEOTrackerPage'));
const GoogleAuthCallbackDebug = React.lazy(() => import('./components/auth/GoogleAuthCallbackDebug'));

// Composant de loading pour les pages lazy
const PageLoadingFallback: React.FC = () => (
  <div className="min-h-screen flex items-center justify-center bg-white dark:bg-gray-900">
    <div className="text-center">
      <div className="loading-spinner mx-auto mb-4"></div>
      <p className="text-gray-600 dark:text-gray-400">Chargement en cours...</p>
    </div>
  </div>
);

const App: React.FC = () => {
  const { t, i18n } = useUpackuTranslation({ ns: 'meta' });
  
  // Hooks d'optimisation SEO pour améliorer les Core Web Vitals
  const seoOptimizer = useSEOPerformanceOptimizer();
  const seoPerformance = useSEOPerformance({
    enableLazyLoading: true,
    enablePreloading: true,
    enableCriticalCSS: true,
    enableImageOptimization: true,
    reportWebVitals: true
  });

  // Service Worker pour mise en cache et performances
  const { status: swStatus, preloadResources } = useServiceWorker(true);
  useEffect(() => {
    // Initialisation des optimisations SEO
    seoOptimizer.preloadCriticalResources();
    seoOptimizer.inlineCriticalCSS();
    
    // Précharger des ressources critiques via SW une fois disponible
    if (swStatus.isControlling) {
      preloadResources([
        '/assets/images/hero-bg.webp',
        '/assets/images/features-preview.webp',
        '/assets/css/main.css'
      ]);
    }
    
    // Log des métriques pour debugging (dev seulement)
    if (process.env.NODE_ENV === 'development') {
      console.log('🚀 SEO Performance Metrics:', {
        optimizer: seoOptimizer.metrics,
        performance: seoPerformance.metrics,
        optimizationScore: seoOptimizer.optimizationScore,
        serviceWorker: swStatus
      });
    }
  }, [seoOptimizer, seoPerformance, swStatus.isControlling, preloadResources]);

  useEffect(() => {
    // Mise à jour des métadonnées en fonction de la langue
    const updateMetaTags = () => {
      document.title = t('title');
      
      // Meta description
      document.querySelector('meta[name="description"]')?.setAttribute('content', t('description'));
      
      // Open Graph
      document.querySelector('meta[property="og:title"]')?.setAttribute('content', t('og.title'));
      document.querySelector('meta[property="og:description"]')?.setAttribute('content', t('og.description'));
      
      // Twitter
      document.querySelector('meta[name="twitter:title"]')?.setAttribute('content', t('twitter.title'));
      document.querySelector('meta[name="twitter:description"]')?.setAttribute('content', t('twitter.description'));
    };

    updateMetaTags();
  }, [t, i18n.language]);
  return (
    <ThemeProvider>
      <Router>
        <SEO />
        <CriticalResourceLoader />
        <div className="min-h-screen transition-colors duration-300 bg-white dark:bg-gray-900 relative">
          {/* Navbar avec z-index très élevé pour se superposer à toutes les sections */}
          <div className="fixed top-0 left-0 right-0 z-[1000]">
            <Navbar />
          </div>
            {/* Configuration des routes avec lazy loading */}
          <Suspense fallback={<PageLoadingFallback />}>
            <Routes>
              {/* Route principale - Page d'accueil */}
              <Route path="/" element={<HomePage />} />
              
              {/* Route publique pour le tracker SEO */}
              <Route path="/seo-tracker" element={<SEOTrackerPage />} />
                {/* Route pour le callback OAuth Google Search Console */}
              <Route path="/auth/google/callback" element={<GoogleAuthCallbackDebug />} />
              
              {/* Route de fallback pour les URLs non trouvées */}
              <Route path="*" element={<HomePage />} />
            </Routes>
          </Suspense>

          <Footer />
          
          {/* Moniteur de performance SEO - Désactivé en production pour la sécurité */}
          {process.env.NODE_ENV === 'development' && (
            <PerformanceMonitor isDevelopment={true} showDetailedMetrics={false} />
          )}
        </div>
      </Router>
    </ThemeProvider>
  );
};

export default App;

